from app.models import User
from app.modules import bootstrap, csrf, db, login_manager, mail
from config import Config

from flask import Flask
from flask_wtf.csrf import CSRFError
from flask.json import jsonify
from werkzeug.middleware.proxy_fix import ProxyFix

from datetime import datetime

def create_app():
    app = Flask(__name__)
    app.config.from_object(Config())
    app.wsgi_app = ProxyFix(app.wsgi_app, x_proto= 1, x_host= 1)

    bootstrap.init_app(app)
    csrf.init_app(app)
    db.init_app(app)
    login_manager.init_app(app)
    mail.init_app(app)

    login_manager.login_view = 'admin._login'
    @login_manager.user_loader
    def _load_user(id):
        return User.query.filter_by(id=id).first()

    @app.errorhandler(404)
    def _404_handler(error):
        return jsonify({'error':'404 &mdash; Not Found'}), 404
    @app.errorhandler(CSRFError)
    def _csrf_handler():
        return jsonify({'error':'Could not validate a secure connection.'}), 403
    @app.context_processor
    def _now():
        return {'now': datetime.now()}

    from app.admin.views import admin
    from app.api.views import api
    from app.views import views
    from app.quiz.views import quiz

    app.register_blueprint(admin, url_prefix='/admin')
    app.register_blueprint(api, url_prefix='/api')
    app.register_blueprint(views)
    app.register_blueprint(quiz)

    return app

app = create_app()

if __name__ == '__main__':
    from app.install import install_scripts
    install_scripts()
    app.run()